# FishingForPhish (WORKING PROJECT)

A phishing detection framework that focuses on the detection of image and page based features. Classes and methods are provided for collecting data regarding proposed image-based features and page-based features from existing research, as well as for new features in order to attempt to determine new patterns or relationships. Selenium Webdriver, Python Weka Wrapper 3, Beautiful Soup, and ImageMagick are primarily used for feature detection. The classes and methods provided by this package are documented in the API section. An analysis of the detected features and resulting data thereof can be found here: https://github.com/xanmankey/FishingForPhish/blob/main/research/FishingForPhish.md.

## Development Status

This project is currently under active development. Contributions and adaptations of the methodology outlined in the research are encouraged.

## Resources
- Documentation: https://fishingforphish.readthedocs.io/en/latest/
- Website: TODO (the server-side code still has to be finalized, and a plan needs to be figured out 
regarding production deployment and hosting)
- PyPi: TODO
